Learn R Programming

Rokemon (version 0.0.1)

poke_pal: Pokemon inspired Palettes

Description

Color palettes generated from Pokemon sprites.

Usage

poke_pal(name, n)

display_poke_pal(name = "pikachu")

Arguments

name

string. name of a Pokemon who's colors should be used

n

integer specifying the number of colors to return.

Value

A color palette

Details

display_poke_pal can be used to display colors of a poke palette. All palettes were computed automatically and might not all be very meaningful. Other (and better) pokemon palettes can be found in the package palettetown

Examples

Run this code
# NOT RUN {
poke_pal("pikachu",3)
# }

Run the code above in your browser using DataLab