Create Pie Charts of the color distribution of Pokemon sprites.
poke_pie(path_to_sprites = "", poke)path to sprite files. See Details
name or pokedex number of Pokemon
Sprites are not provided and have to be download prior of usage. It is important that the sprites are numbered from 1.png to 801.png. https://github.com/PokeAPI/sprites contains all sprites in the right format and has been used for testing.